###########################
Aldryn Bootstrap3
###########################

|PyPI Version| |Build Status| |Coverage Status|

aldryn-bootstrap3 is a plugin bundle provided for django CMS. This package extends the most used components of the `Bootstrap <http://getbootstrap.com/>`_ framework. It uses a variety of components for rapid frontend development and implements various best practices from within the front-end community.

following plugins are available:

* `Grid (Row and Column) <http://getbootstrap.com/css/#grid/>`_
* `Button and Link <http://getbootstrap.com/css/#buttons>`_
* `Image <http://getbootstrap.com/css/#images>`_
* Icon (`Fontawesome <http://fortawesome.github.io/Font-Awesome/>`_ and `Glyphicons <http://getbootstrap.com/components/#glyphicons>`_)
* `Blockquote <http://getbootstrap.com/css/#type-blockquotes>`_
* `Label <http://getbootstrap.com/components/#labels>`_
* `Well <http://getbootstrap.com/components/#wells>`_
* `Alert <http://getbootstrap.com/components/#alerts>`_
* `Panel (Heading, Body and Footer) <http://getbootstrap.com/components/#panels>`_
* `Accordion <http://getbootstrap.com/javascript/#collapse-example-accordion>`_
* `ListGroup <http://getbootstrap.com/components/#list-group>`_
* `Carousel <http://getbootstrap.com/javascript/#carousel>`_
* `Spacer <https://github.com/aldryn/aldryn-bootstrap3/wiki/13-spacer>`_
*************
Documentation
*************

For further information about usage `read the docs <https://github.com/aldryn/aldryn-bootstrap3/wiki>`_.

************
Contribution
************

You are very welcome improving this addon for Aldryn and your everyday use, especially the documentation always
needs love. Feel free to fork and send us pull requests and checkout the
`contribution guide <http://aldryn-boilerplate-bootstrap3.readthedocs.org/en/latest/contribution/index.html>`_ within our documentation.

.. |PyPI Version| image:: http://img.shields.io/pypi/v/aldryn-bootstrap3.svg
   :target: https://pypi.python.org/pypi/aldryn-bootstrap3
.. |Build Status| image:: http://img.shields.io/travis/aldryn/aldryn-bootstrap3/master.svg
   :target: https://travis-ci.org/aldryn/aldryn-bootstrap3
.. |Coverage Status| image:: http://img.shields.io/coveralls/aldryn/aldryn-bootstrap3/master.svg
   :target: https://coveralls.io/r/aldryn/aldryn-bootstrap3?branch=master
